##  Translations
To view translations for a specific item (such as subsection, relation, or field), select it, then go to the Translations tab on the right-side panel. You can edit translations for labels and help text (if applicable). To streamline the translation process, use AI-supported translation. For more information, see [AI-Supported Translation](https://help.sap.com/docs/leanix/ea/base-ai-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758e1767a441014b89cdbb68f4cded0__ai-supported_translation).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27509f497a441014b0dca52f01439a58_LowRes.png)
"Translations" Tab on the Configuration Panel
